from IPython.core.compilerop import CachingCompiler


class XCachingCompiler(CachingCompiler):
    def __init__(self, *args, **kwargs):
        super(XCachingCompiler, self).__init__(*args, **kwargs)

        self.filename_mapper = None
        self.get_filename = None

    def get_code_name(self, raw_code, code, number):
        if self.get_filename is not None:
            filename = self.get_filename(raw_code)
        else:
            filename = '<string>'

        if self.filename_mapper is not None:
            self.filename_mapper(filename, number)

        return filename



#!/usr/bin/env python

from setuptools import setup, find_packages

__AUTHOR__ = 'QuantStack dev team'

setup(
    name='xeus-python-shell',
    version='0.1.1',
    description='The xeus-python core python logic.',
    author=__AUTHOR__,
    maintainer=__AUTHOR__,
    url='https://github.com/jupyter-xeus/xeus-python-shell',
    license='BSD 3-Clause',
    keywords='python ipython xeus-python',
    packages=find_packages(exclude=['test']),
    python_requires='>=3.6',
    install_requires=[
        'ipython>=7.21,<8'
    ],
    extras_require={
        'testing': ['flake8'],
    },
    platforms=['any'],
    classifiers=[
        'Intended Audience :: Developers',
        'Operating System :: OS Independent',
        'Programming Language :: Python :: 3',
        'Programming Language :: Python :: 3.6',
        'Programming Language :: Python :: 3.7',
        'Programming Language :: Python :: 3.8',
        'Programming Language :: Python :: 3.9',
        'Topic :: Software Development :: Libraries :: Python Modules',
    ],
)
